@@ -7,39 +7,39 @@
 #ifndef PRISON_BARCODEQUICKITEM_H
 #define PRISON_BARCODEQUICKITEM_H
 
-#include <Prison/Prison>
+#include <Prison/Barcode>
 
 #include <QColor>
 #include <QQuickPaintedItem>
 
-#include <memory>
+#include <qqmlregistration.h>
 
 namespace Prison
 {
-class AbstractBarcode;
 
 class BarcodeQuickItem : public QQuickPaintedItem
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(Barcode)
     Q_PROPERTY(QVariant content READ content WRITE setContent NOTIFY contentChanged)
-    Q_PROPERTY(BarcodeType barcodeType READ barcodeType WRITE setBarcodeType NOTIFY barcodeTypeChanged)
+    Q_PROPERTY(QJSValue barcodeType READ barcodeType WRITE setBarcodeType NOTIFY barcodeTypeChanged)
     Q_PROPERTY(QColor foregroundColor READ foregroundColor WRITE setForegroundColor NOTIFY foregroundColorChanged)
     Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor NOTIFY backgroundColorChanged)
     Q_PROPERTY(Dimensions dimensions READ dimensions NOTIFY dimensionsChanged)
     /**
-     * @see Prison::AbstractBarcode::trueMinimumSize()
+     * @see Prison::Barcode::minimumSize()
      * @since 5.69
      */
     Q_PROPERTY(qreal minimumHeight READ minimumHeight NOTIFY implicitHeightChanged)
     /**
-     * @see Prison::AbstractBarcode::trueMinimumSize()
+     * @see Prison::Barcode::minimumSize()
      * @since 5.69
      */
     Q_PROPERTY(qreal minimumWidth READ minimumWidth NOTIFY implicitWidthChanged)
 
 public:
     enum BarcodeType {
-        Null = Prison::Null,
         QRCode = Prison::QRCode,
         DataMatrix = Prison::DataMatrix,
         Aztec = Prison::Aztec,
@@ -47,6 +47,7 @@ public:
         Code93 = Prison::Code93,
         Code128 = Prison::Code128,
         PDF417 = Prison::PDF417,
+        EAN13 = Prison::EAN13,
     };
     Q_ENUM(BarcodeType)
     explicit BarcodeQuickItem(QQuickItem *parent = nullptr);
@@ -55,8 +56,8 @@ public:
     QVariant content() const;
     void setContent(const QVariant &data);
 
-    Prison::BarcodeQuickItem::BarcodeType barcodeType() const;
-    void setBarcodeType(Prison::BarcodeQuickItem::BarcodeType type);
+    QJSValue barcodeType() const;
+    void setBarcodeType(const QJSValue &type);
 
     QColor foregroundColor() const;
     void setForegroundColor(const QColor &color);
@@ -68,7 +69,7 @@ public:
         OneDimension,
         TwoDimensions,
     };
-    Q_ENUM(Dimensions);
+    Q_ENUM(Dimensions)
     Dimensions dimensions() const;
 
     void paint(QPainter *painter) override;
@@ -89,10 +90,10 @@ private:
     void updateBarcode();
 
     QVariant m_content;
-    std::unique_ptr<AbstractBarcode> m_barcode;
+    std::optional<Barcode> m_barcode;
     QColor m_fgColor = Qt::black;
     QColor m_bgColor = Qt::white;
-    Prison::BarcodeType m_type = Prison::Null;
+    std::optional<Prison::BarcodeType> m_type;
 };
 
 }
